[![Bob Logo](/doc/BOB_Logo.png?raw=true)](https://bobbuildtool.github.io/)

[Bob Build Tool](https://bobbuildtool.github.io/)
=================================================

Bob is a build automation tool inspired by bitbake and portage. It is intended
for complex embedded projects and thus focuses on reproducible builds while
still being nice to developers in agile environments.

[![Documentation Status](http://readthedocs.org/projects/bob-build-tool/badge/?version=latest)](http://bob-build-tool.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/BobBuildTool/bob.svg?branch=master)](https://travis-ci.org/BobBuildTool/bob)
[![codecov.io](https://codecov.io/github/BobBuildTool/bob/coverage.svg?branch=master)](https://codecov.io/github/BobBuildTool/bob?branch=master)

Installation
============

To install the latest release just do a:

    $ python3 -m pip install BobBuildTool [--user]

See the [installation instructions](https://bob-build-tool.readthedocs.io/en/latest/installation.html)
for more information and other methods.

Getting started
===============

It's probably the best to head over to the
[documentation](http://bob-build-tool.readthedocs.io/). To get an impression
of how Bob is configured, have a look at the
[tutorials](https://github.com/BobBuildTool/bob-tutorials). A real project that
is built by Bob can be found [here](https://github.com/BobBuildTool/basement).

If you have a specific question you're welcome to post on the
[mailing list](mailto:bob-build-tool@freelists.org)
([FreeLists](http://www.freelists.org/list/bob-build-tool)).
